Module cp

Module cp 

cp command - Copy objects

Copies objects between local filesystem and S3, or between S3 locations.

Structs

CpArgs
Copy objects
GetArgs
Download one remote object through the canonical copy implementation.
PutArgs
Upload one or more local paths through the canonical copy implementation.

Functions

execute
Execute the cp command
execute_get
Execute the mc-compatible get command through the canonical copy path.
execute_put
Execute the mc-compatible put command through the canonical copy path.