pub struct Formatter { /* private fields */ }Expand description
Formatter for CLI output
Handles both human-readable and JSON output formats based on configuration. When JSON mode is enabled, all output is strict JSON without colors or progress.
Implementations
Sourceimpl Formatter
impl Formatter
Sourcepub fn new(config: OutputConfig) -> Self
pub fn new(config: OutputConfig) -> Self
Create a new formatter with the given configuration
Sourcepub fn colors_enabled(&self) -> bool
pub fn colors_enabled(&self) -> bool
Check if colors are enabled
Sourcepub fn output_config(&self) -> OutputConfig
pub fn output_config(&self) -> OutputConfig
Get a clone of the output configuration
Sourcepub fn style_file(&self, text: &str) -> String
pub fn style_file(&self, text: &str) -> String
Style a file name (default)
Sourcepub fn style_size(&self, text: &str) -> String
pub fn style_size(&self, text: &str) -> String
Style a file size (green)
Sourcepub fn style_date(&self, text: &str) -> String
pub fn style_date(&self, text: &str) -> String
Style a timestamp/date (dim)
Sourcepub fn style_name(&self, text: &str) -> String
pub fn style_name(&self, text: &str) -> String
Style an alias/bucket name (bold)
Sourcepub fn style_tree_branch(&self, text: &str) -> String
pub fn style_tree_branch(&self, text: &str) -> String
Style tree branch characters (dim)
Sourcepub fn output<T: Serialize + Display>(&self, value: &T)
pub fn output<T: Serialize + Display>(&self, value: &T)
Output a value
In JSON mode, serializes the value to JSON. In human mode, uses the Display implementation.
Sourcepub fn error(&self, message: &str)
pub fn error(&self, message: &str)
Output an error message
Errors are always printed, even in quiet mode.
Sourcepub fn error_with_code(&self, code: ExitCode, message: &str)
pub fn error_with_code(&self, code: ExitCode, message: &str)
Output an error message with an explicit exit code.
Sourcepub fn error_with_suggestion(
&self,
code: ExitCode,
message: &str,
suggestion: &str,
)
pub fn error_with_suggestion( &self, code: ExitCode, message: &str, suggestion: &str, )
Output an error message with an explicit exit code and recovery suggestion.
Sourcepub fn fail(&self, code: ExitCode, message: &str) -> ExitCode
pub fn fail(&self, code: ExitCode, message: &str) -> ExitCode
Print an error and return the provided exit code.
Sourcepub fn fail_with_suggestion(
&self,
code: ExitCode,
message: &str,
suggestion: &str,
) -> ExitCode
pub fn fail_with_suggestion( &self, code: ExitCode, message: &str, suggestion: &str, ) -> ExitCode
Print an error with a recovery hint and return the provided exit code.