pub struct CpArgs {Show 28 fields
pub sources: Vec<String>,
pub target: String,
pub recursive: bool,
pub preserve: bool,
pub continue_on_error: bool,
pub overwrite: bool,
pub skip_existing: bool,
pub dry_run: bool,
pub storage_class: Option<String>,
pub content_type: Option<String>,
pub enc_s3: Vec<String>,
pub enc_kms: Vec<String>,
pub enc_c_source_key_file: Option<PathBuf>,
pub enc_c_source_key_env: Option<String>,
pub enc_c_destination_key_file: Option<PathBuf>,
pub enc_c_destination_key_env: Option<String>,
pub include: Vec<String>,
pub exclude: Vec<String>,
pub newer_than: Option<String>,
pub older_than: Option<String>,
pub rewind: Option<String>,
pub concurrency: Option<usize>,
pub rate_limit: Option<String>,
pub retry_attempts: Option<u32>,
pub retry_initial_backoff_ms: Option<u64>,
pub retry_max_backoff_ms: Option<u64>,
pub fail_empty: bool,
pub summary: bool,
/* private fields */
}Expand description
Copy objects
Fields
sources: Vec<String>Source paths (local paths or alias/bucket/key)
target: StringDestination path (local path or alias/bucket/key)
recursive: boolCopy recursively
preserve: boolPreserve file attributes
continue_on_error: boolContinue on errors
overwrite: boolOverwrite destination if it exists
skip_existing: boolSkip remote destinations that already exist
dry_run: boolOnly show what would be copied (dry run)
storage_class: Option<String>Storage class for destination (S3 only)
content_type: Option<String>Content type for uploaded files
enc_s3: Vec<String>Apply SSE-S3 to the remote destination path
enc_kms: Vec<String>Apply SSE-KMS to the remote destination path as TARGET=KMS_KEY_ID
enc_c_source_key_file: Option<PathBuf>Read a 32-byte SSE-C source key from a protected file
enc_c_source_key_env: Option<String>Read a 32-byte SSE-C source key from the named environment variable
enc_c_destination_key_file: Option<PathBuf>Read a 32-byte SSE-C destination key from a protected file
enc_c_destination_key_env: Option<String>Read a 32-byte SSE-C destination key from the named environment variable
include: Vec<String>Include source-relative paths matching this glob (repeatable)
exclude: Vec<String>Exclude source-relative paths matching this glob; exclusions always win (repeatable)
newer_than: Option<String>Select objects modified more recently than this age (for example 1h or 7d)
older_than: Option<String>Select objects modified less recently than this age (for example 1h or 7d)
rewind: Option<String>Select object state at or before a UTC timestamp or age
concurrency: Option<usize>Maximum number of transfers in flight across the command
rate_limit: Option<String>Aggregate transfer start rate in bytes per second (for example 10MiB/s)
retry_attempts: Option<u32>Maximum attempts for transient transfer failures
retry_initial_backoff_ms: Option<u64>Initial transient retry backoff in milliseconds
retry_max_backoff_ms: Option<u64>Maximum transient retry backoff in milliseconds
fail_empty: boolReturn not-found when selection produces no transfer candidates
summary: boolPrint deterministic aggregate transfer counters (human output)